==> billogram-foundation-3.12.0.tgz: package/modules/components/monthpicker/MonthpickerContainer.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { mount } from 'enzyme';
import { Provider } from 'react-redux';

import Monthpicker from './Monthpicker';
import MonthpickerContainer, { changeType } from './MonthpickerContainer';

import monthpickerChange from './redux/monthpickerChange';
import monthpickerState from './redux/monthpickerState';

import createStore from '../../test-utils/createStore';


const TestMonthpicker = Monthpicker({
    block: purebem.of('test-monthpicker'),
    displayName: 'TestMonthpicker'
});

const TestMonthpickerContainer = MonthpickerContainer({
    Component: TestMonthpicker
});

const path = 'picker';
const root = 'test';
const actionTypePrefix = 'TEST-MONTHPICKER';

test('should dispatch change event when clicking next', () => {
    const store = createStore({
        test: {
            picker: monthpickerState({
                value: +new Date(2000, 0, 1)
            })
        }
    });

    const wrapper = mount(
        <Provider store={ store }>
            <TestMonthpickerContainer
                actionTypePrefix={ actionTypePrefix }
                customActionMetadata={ { index: 1 } }
                path={ path }
                root={ root } />
        </Provider>
    );

    wrapper.find('TestMonthpickerNextMonth').simulate('click');

    const actions = store.getState().actions;

    expect(actions.length).toBe(1);
    expect(actions[0]).toEqual(monthpickerChange({
        custom: { index: 1 },
        path,
        root,
        type: changeType(actionTypePrefix),
        value: +new Date(2000, 1, 1)
    }));
});


test('should dispatch change event when clicking previous', () => {
    const store = createStore({
        test: {
            picker: monthpickerState({
                value: +new Date(2000, 0, 1)
            })
        }
    });

    const wrapper = mount(
        <Provider store={ store }>
            <TestMonthpickerContainer
                actionTypePrefix={ actionTypePrefix }
                customActionMetadata={ { index: 1 } }
                path={ path }
                root={ root } />
        </Provider>
    );

    wrapper.find('TestMonthpickerPreviousMonth').simulate('click');

    const actions = store.getState().actions;

    expect(actions.length).toBe(1);
    expect(actions[0]).toEqual(monthpickerChange({
        custom: { index: 1 },
        path,
        root,
        type: changeType(actionTypePrefix),
        value: +new Date(1999, 11, 1)
    }));
});

==> billogram-foundation-3.13.10.tgz: package/modules/components/monthpicker/MonthpickerContainer.jest.js <==
import React from 'react';
import purebem from 'purebem';
import { mount } from 'enzyme';
import { Provider } from 'react-redux';

import Monthpicker from './Monthpicker';
import MonthpickerContainer, { changeType } from './MonthpickerContainer';

import monthpickerChange from './redux/monthpickerChange';
import monthpickerState from './redux/monthpickerState';

import createStore from '../../test-utils/createStore';


const TestMonthpicker = Monthpicker({
    block: purebem.of('test-monthpicker'),
    displayName: 'TestMonthpicker'
});

const TestMonthpickerContainer = MonthpickerContainer({
    Component: TestMonthpicker
});

const actionTypePrefix = 'TEST-MONTHPICKER';
const path = 'component';
const root = 'test';

test('should dispatch change event when clicking next', () => {
    const store = createStore({
        [root]: {
            [path]: monthpickerState({
                value: +new Date(2000, 0, 1)
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestMonthpickerContainer
                actionTypePrefix={ actionTypePrefix }
                customActionMetadata={ { index: 1 } }
                path={ path }
                root={ root } />
        </Provider>
    );

    provider.find('TestMonthpickerNextMonth').simulate('click');

    const actions = store.getState().actions;

    expect(actions.length).toBe(1);
    expect(actions[0]).toEqual(monthpickerChange({
        custom: { index: 1 },
        path,
        root,
        type: changeType(actionTypePrefix),
        value: +new Date(2000, 1, 1)
    }));
});


test('should dispatch change event when clicking previous', () => {
    const store = createStore({
        [root]: {
            [path]: monthpickerState({
                value: +new Date(2000, 0, 1)
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestMonthpickerContainer
                actionTypePrefix={ actionTypePrefix }
                customActionMetadata={ { index: 1 } }
                path={ path }
                root={ root } />
        </Provider>
    );

    provider.find('TestMonthpickerPreviousMonth').simulate('click');

    const actions = store.getState().actions;

    expect(actions.length).toBe(1);
    expect(actions[0]).toEqual(monthpickerChange({
        custom: { index: 1 },
        path,
        root,
        type: changeType(actionTypePrefix),
        value: +new Date(1999, 11, 1)
    }));
});

test('should read value from store', () => {
    const store = createStore({
        [root]: {
            [path]: monthpickerState({
                value: +new Date(2000, 0, 1)
            })
        }
    });

    const provider = mount(
        <Provider store={ store }>
            <TestMonthpickerContainer
                actionTypePrefix={ actionTypePrefix }
                customActionMetadata={ { index: 1 } }
                path={ path }
                root={ root } />
        </Provider>
    );

    expect(provider.find(TestMonthpicker).prop('value')).toBe(+new Date(2000, 0, 1));
});
